@@ -142,7 +142,7 @@ class BaseObject(object):
 		Remove the object (and optionally its child nodes) from the LDAP database.
 
 		:param bool remove_childs: if there are UDM objects below this objects DN, recursively remove
-		    them before removing this object
+			them before removing this object
 		:return: None
 		"""
 		raise NotImplementedError()
@@ -324,7 +324,7 @@ class BaseModule(with_metaclass(ModuleMeta)):
 					self.name, self.meta.identifying_property, filter_s, len(res)), module_name=self.name)
 		return res[0]
 
-	def search(self, filter_s='', base='', scope='sub'):
+	def search(self, filter_s='', base='', scope='sub', sizelimit=0):
 		"""
 		Get all |UDM| objects from |LDAP| that match the given filter.
 
@@ -332,6 +332,7 @@ class BaseModule(with_metaclass(ModuleMeta)):
 			required, `objectClasses` will be set by the |UDM| module)
 		:param str base: |LDAP| search base.
 		:param str scope: |LDAP| search scope, e.g. `base` or `sub` or `one`.
+		:param int sizelimit: |LDAP| size limit for searched results.
 		:return: iterator of :py:class:`BaseObject` objects
 		:rtype: Iterator(BaseObject)
 		"""
